@@ -145,7 +145,7 @@ class DB:
             expression_values = {}
             for name, value in expect_if_item_exists.items():
                 hashed_name = self._hash_name(name)
-                statements.append(f"#{hashed_name}=:{hashed_name}")
+                statements.append(f"#{hashed_name} = :{hashed_name}")
                 expression_names[f"#{hashed_name}"] = name
                 expression_values[f":{hashed_name}"] = value
             condition_expression = " AND ".join(statements)
@@ -172,7 +172,8 @@ class DB:
         assert not key.secondary or key.secondary.name in item
 
         def build_expression():  # apply diff
-            statements = []
+            set_actions = []
+            delete_actions = []
             names = {}
             values = {}
 
@@ -183,28 +184,37 @@ class DB:
                     for sub_name, sub_value in value.items():
                         hashed_sub_name = self._hash_name(sub_name)
                         if sub_name not in old_item[name] or old_item[name][sub_name] != sub_value:
-                            statements.append(f"SET #{hashed_name}.#{hashed_sub_name}=:{hashed_name + hashed_sub_name}")
+                            set_actions.append(
+                                f"#{hashed_name}.#{hashed_sub_name} = :{hashed_name + hashed_sub_name}"
+                            )
+                            names[f"#{hashed_name}"] = name
                             names[f"#{hashed_sub_name}"] = sub_name
                             values[f":{hashed_name + hashed_sub_name}"] = sub_value
 
                     for old_sub_name in old_item.get(name, {}):
                         if old_sub_name not in value:
                             hashed_old_sub_name = self._hash_name(old_sub_name)
-                            statements.append(f"DELETE #{hashed_name}.#{hashed_old_sub_name}")
+                            delete_actions.append(f"#{hashed_name}.#{hashed_old_sub_name}")
+                            names[f"#{hashed_name}"] = name
                             names[f"#{hashed_old_sub_name}"] = old_sub_name
 
                 elif name not in old_item or old_item[name] != value:
-                    statements.append(f"SET #{hashed_name}=:{hashed_name}")
+                    set_actions.append(f"#{hashed_name} = :{hashed_name}")
                     names[f"#{hashed_name}"] = name
                     values[f":{hashed_name}"] = value
 
             for old_name in old_item:
                 if old_name not in item:
                     hashed_old_name = self._hash_name(old_name)
-                    statements.append(f"DELETE #{hashed_old_name}")
+                    delete_actions.append(f"#{hashed_old_name}")
                     names[f"#{hashed_old_name}"] = old_name
 
-            return ", ".join(statements), names, values
+            clauses = []
+            if set_actions:
+                clauses.append("SET " + ", ".join(set_actions))
+            if delete_actions:
+                clauses.append("DELETE " + ", ".join(delete_actions))
+            return " ".join(clauses), names, values
 
         expression, expression_names, expression_values = build_expression()
 
